#include <stdio.h>
#include <stdlib.h>
#include <signal.h>
#include <unistd.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <pwd.h>
#include <sys/soundcard.h>

#define BUFSIZE 4096

char dspstr[255], mixstr[255];
int source = 0;
int samplerate = 0;
int bitrate = 0;
int stereo = 0;
int lvol = 0;
int rvol = 0;
int tracknum = 1;
int recording = 0;
int playing = 0;


void SetupAudio(int *fd) {

  int mixfd, dspfd;
  int mask;
  int volume;
  int src;


  if ((mixfd = open(mixstr, O_RDWR)) == -1) {
    fprintf(stderr, "Could not open audio mixer device.\n");
    *fd = -1;
    return;
  }

  if (ioctl(mixfd, SOUND_MIXER_READ_RECMASK, &mask) == -1)
    fprintf(stderr, "Could not query audio mixer device.\n");
  else
    if (mask && source) {
      src = 1<<source;
      ioctl(mixfd, SOUND_MIXER_WRITE_RECSRC, &src);
      volume = (rvol << 8)|lvol;
      ioctl(mixfd, MIXER_WRITE(source), &volume);
    }
  close (mixfd);

  if ((dspfd = open(dspstr, O_RDONLY)) == -1) {
     fprintf(stderr, "Could not open audio DSP device.\n");
     *fd = -1;
     return;
  }

  src = bitrate;
  if (ioctl (dspfd, SNDCTL_DSP_SAMPLESIZE, &src) <0) {
    fprintf (stderr, "Unable to set audio sample size.\n");
    close (dspfd);
    *fd = -1;
    return;
  }
  else
    bitrate = src;

  src = stereo;
  if (ioctl(dspfd, SNDCTL_DSP_STEREO, &src) <0) {
    fprintf (stderr, "Unable to set audio channels.\n");
    close (dspfd);
    *fd = -1;
    return;
  }
  else
    stereo = src;

  src = samplerate;
  if (ioctl(dspfd, SNDCTL_DSP_SPEED, &src) <0) {
    fprintf (stderr, "Unable to set sample rate.\n");
    close (dspfd);
    *fd = -1;
    return;
  }
  else
    samplerate = src;

  *fd = dspfd;

  return;
}

void sb_init(void)
{
   strcpy(dspstr,"/dev/dsp");
   strcpy(mixstr,"/dev/mixer");
   source = SOUND_MIXER_MIC;
   samplerate=11025;
   bitrate=8;
   lvol=0;
   rvol=0;
   stereo=0;
}
